@@ -64,20 +64,10 @@ pub trait UsizeEncoding: private::Sealed {
     where
         W: Writer;
 
-    /// Governs how usize lengths are encoded into a [Writer].
-    fn encode_typed_usize<W>(writer: W, value: usize) -> Result<(), W::Error>
-    where
-        W: Writer;
-
     /// Governs how usize lengths are decoded from a [Reader].
     fn decode_usize<'de, R>(reader: R) -> Result<usize, R::Error>
     where
         R: Reader<'de>;
-
-    /// Governs how usize lengths are decoded from a [Reader].
-    fn decode_typed_usize<'de, R>(reader: R) -> Result<usize, R::Error>
-    where
-        R: Reader<'de>;
 }
 
 /// Type that indicates that the given numerical type should use variable-length
@@ -137,14 +127,6 @@ impl UsizeEncoding for Variable {
         c::encode(writer, value)
     }
 
-    #[inline]
-    fn encode_typed_usize<W>(writer: W, value: usize) -> Result<(), W::Error>
-    where
-        W: Writer,
-    {
-        c::encode(writer, value)
-    }
-
     #[inline]
     fn decode_usize<'de, R>(reader: R) -> Result<usize, R::Error>
     where
@@ -152,14 +134,6 @@ impl UsizeEncoding for Variable {
     {
         c::decode(reader)
     }
-
-    #[inline]
-    fn decode_typed_usize<'de, R>(reader: R) -> Result<usize, R::Error>
-    where
-        R: Reader<'de>,
-    {
-        c::decode(reader)
-    }
 }
 
 /// A fixed-length integer encoding which encodes something to the specified
@@ -245,15 +219,6 @@ where
         value.write_bytes::<_, B>(writer)
     }
 
-    #[inline]
-    fn encode_typed_usize<W>(writer: W, value: usize) -> Result<(), W::Error>
-    where
-        W: Writer,
-    {
-        let value: L = value.try_into().map_err(W::Error::custom)?;
-        value.write_bytes::<_, B>(writer)
-    }
-
     #[inline]
     fn decode_usize<'de, R>(reader: R) -> Result<usize, R::Error>
     where
@@ -261,12 +226,4 @@ where
     {
         usize::try_from(L::read_bytes::<_, B>(reader)?).map_err(R::Error::custom)
     }
-
-    #[inline]
-    fn decode_typed_usize<'de, R>(reader: R) -> Result<usize, R::Error>
-    where
-        R: Reader<'de>,
-    {
-        usize::try_from(L::read_bytes::<_, B>(reader)?).map_err(R::Error::custom)
-    }
 }
